import{_ as C}from"./logo.084e5d7c.js";import{x,b as r,ew as p,eC as I,eD as w,e as d,d as k,eK as N,a as D,u as e,c,bh as L,w as t,f as s,as as l,eH as m,bG as f,cC as S,cy as $,eO as V,eF as z,f9 as E,aE as g,ey as F,dj as R}from"./outputWidgets.6e1c5425.js";import{b as h,c as T}from"./router.4a0ba06b.js";import{a as j}from"./asyncComputed.06ede41f.js";import{F as H}from"./PhSignOut.vue.8b6374ae.js";import{A as O}from"./Text.b10c1140.js";import{A as P}from"./index.2d522974.js";import{B as q,A as G,b as K}from"./index.8f97a60b.js";import{B as M}from"./BookOutlined.8202b78f.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[a]="eee2224a-1469-4418-86a5-7b67b46dd0e2",o._sentryDebugIdIdentifier="sentry-dbid-eee2224a-1469-4418-86a5-7b67b46dd0e2")}catch{}})();const U={},v=o=>(I("data-v-46e041c1"),o=o(),w(),o),J={class:"logo"},Q=v(()=>d("img",{class:"logo-img",src:C,alt:"Abstra cloud logo"},null,-1)),W=v(()=>d("span",null,"Abstra",-1)),X=[Q,W];function Y(o,a){return r(),p("div",J,X)}const Z=x(U,[["render",Y],["__scopeId","data-v-46e041c1"]]),ee={style:{display:"flex","flex-direction":"column",gap:"10px"}},te={style:{display:"flex",gap:"5px"}},oe=k({__name:"LoginBlock",setup(o){function a(b){const y=b.split("@")[0];return V.exports.kebabCase(y).toUpperCase().split("-").slice(0,2).map(u=>u[0]).join("")}const i=N(),{result:n,loading:_,refetch:A}=j(async()=>h.getAuthor());function B(){h.removeAuthor(),T.shutdown(),A(),i.push({name:"login"})}return(b,y)=>{const u=D("router-link");return e(_)?(r(),c(e(L),{key:0})):e(n)?(r(),c(e($),{key:1,placement:"bottomRight"},{content:t(()=>[d("div",ee,[s(e(O),{size:"small",type:"secondary"},{default:t(()=>[l(m(e(n).claims.email),1)]),_:1}),s(e(f),{type:"text",onClick:B},{default:t(()=>[d("div",te,[s(e(H),{size:"20"}),l(" Logout ")])]),_:1})])]),default:t(()=>[s(e(S),{align:"center",style:{cursor:"pointer"}},{default:t(()=>[s(e(P),{shape:"square"},{default:t(()=>[l(m(a(e(n).claims.email)),1)]),_:1})]),_:1})]),_:1})):(r(),c(e(f),{key:2},{default:t(()=>[s(u,{to:"/login"},{default:t(()=>[l("Login")]),_:1})]),_:1}))}}}),se={class:"extra"},ae=k({__name:"Navbar",props:{breadcrumb:{}},setup(o){return(a,i)=>(r(),c(e(K),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{subTitle:t(()=>[a.breadcrumb?(r(),c(e(q),{key:0,style:{margin:"0px 50px"}},{default:t(()=>[(r(!0),p(g,null,z(a.breadcrumb,(n,_)=>(r(),c(e(G),{key:_},{default:t(()=>[s(e(E),{to:n.path},{default:t(()=>[l(m(n.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):F("",!0)]),title:t(()=>[s(Z)]),extra:t(()=>[d("div",se,[s(e(f),{class:"docs-button",href:"https://docs.abstra.io/",target:"_blank",type:"link",style:{color:"#d14056"},size:"small"},{icon:t(()=>[s(e(M))]),default:t(()=>[a.$slots.default?R(a.$slots,"default",{key:0},void 0,!0):(r(),p(g,{key:1},[l("Docs")],64))]),_:3}),s(oe)])]),_:3}))}});const me=x(ae,[["__scopeId","data-v-31e2a422"]]);export{me as N};
//# sourceMappingURL=Navbar.10564cb7.js.map
