import{a as e,B as s}from"./Base.0277cf44.js";import{A as a}from"./Link.5b1de2a9.js";import{A as o}from"./Paragraph.4ce326b3.js";import{A as r}from"./Text.b10c1140.js";import{A as i}from"./Title.dfd37452.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[t]="fb75527a-274b-4e90-9901-014a077e2516",n._sentryDebugIdIdentifier="sentry-dbid-fb75527a-274b-4e90-9901-014a077e2516")}catch{}})();e.Text=r;e.Title=i;e.Paragraph=o;e.Link=a;e.Base=s;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,r),n.component(e.Title.displayName,i),n.component(e.Paragraph.displayName,o),n.component(e.Link.displayName,a),n};
//# sourceMappingURL=index.2623066f.js.map
