.item{padding:10px;margin-top:5px;margin-bottom:5px;list-style:none;background-color:#fff;border-radius:5px;border-width:10px;border-color:#000}[data-v-1ae0e521]:root{--main-font-family: DM Sans, sans-serif}[data-v-1ae0e521]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-1ae0e521]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-1ae0e521]{background-color:#fff;padding:10px}.container[data-v-1ae0e521]{width:33%;padding:10px;margin-top:10px;border-radius:5px;background-color:#e9eaeb}.container .container-title[data-v-1ae0e521]{align-items:center;gap:4px}.container .content[data-v-1ae0e521]{height:100%}.container .content .item[data-v-1ae0e521]{cursor:grab}.ghost[data-v-1ae0e521]{opacity:.5;background-color:#8692a5}
