import{d as v,F as A}from"./vuedraggable.umd.203fdeb3.js";import{d as y,r as V,K as x,o as C,eO as c,b as u,c as f,w as o,f as t,u as e,as as h,cC as D,e as s,eH as _,bA as S}from"./outputWidgets.6e1c5425.js";import{_ as F}from"./SaveButton.vue_vue_type_script_setup_true_lang.a37b6a4e.js";import{A as I}from"./Item.c37126c1.js";import{A as L}from"./index.5df58343.js";import{A as w}from"./Title.dfd37452.js";import{A as g}from"./index.c12e1c2f.js";import{A as b}from"./index.e3b3130d.js";import{A as E,F as B}from"./Form.b82a2cec.js";import{S as U}from"./SidebarPreview.944d4391.js";import{C as $}from"./ContentLayout.150390bd.js";import{L as N}from"./LoadingContainer.74576226.js";import{a as R}from"./asyncComputed.06ede41f.js";import{W as T}from"./workspaces.0676e56f.js";import"./envVars.72a577f4.js";import"./UnsavedChangesHandler.77610fef.js";import"./ExclamationCircleOutlined.0240c9dc.js";import"./Modal.e50e9e9a.js";import"./Base.0277cf44.js";import"./Link.5b1de2a9.js";import"./hasIn.bf07751b.js";import"./Home.7e476090.js";import"./PhArrowSquareOut.vue.b51cdf06.js";import"./api.eb323d7c.js";import"./index.5912e808.js";import"./fetch.d2d3ed34.js";import"./pubsub.4f3043c8.js";import"./runnerData.dbd7d7cb.js";import"./url.5357e9db.js";import"./index.2623066f.js";import"./Paragraph.4ce326b3.js";import"./Text.b10c1140.js";import"./index.088b8677.js";import"./Card.8d975aac.js";import"./TabPane.6f71397e.js";import"./PlayerNavbar.854285c0.js";import"./PhKanban.vue.0b81dffb.js";import"./PhSignOut.vue.8b6374ae.js";import"./index.2d522974.js";import"./WidgetsFrame.89e32c21.js";import"./record.c7d63161.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[a]="a02f61f4-e45e-4022-8c53-0bf13f5930fa",r._sentryDebugIdIdentifier="sentry-dbid-a02f61f4-e45e-4022-8c53-0bf13f5930fa")}catch{}})();const j=s("span",null,"Route",-1),K=s("span",null,"Title",-1),M=s("span",null,"Visible",-1),O={style:{flex:"1 0"}},W={style:{flex:"1 0"}},q=y({__name:"SidebarEditor",props:{modelValue:{},workspace:{}},emits:["update:modelValue"],setup(r,{emit:a}){const n=r,i=V([]),p=()=>a("update:modelValue",i.value);return x(()=>n.modelValue,(l,m)=>{c.exports.isEqual(l,m)||(i.value=c.exports.cloneDeep(l))}),C(()=>{i.value=c.exports.cloneDeep(n.modelValue)}),(l,m)=>(u(),f(e(E),{help:"Change your sidebar items position and visibility by dragging them up and down"},{default:o(()=>[t(e(g),{justify:"space-between",style:{margin:"0 0 12px 0"}},{default:o(()=>[t(e(w),{level:4,style:{margin:"0"}},{default:o(()=>[h("Sidebar items")]),_:1}),t(F,{model:l.workspace},null,8,["model"])]),_:1}),t(e(L),{bordered:""},{header:o(()=>[t(e(D),{style:{width:"100%","justify-content":"space-between"}},{default:o(()=>[j,t(e(b),{type:"vertical"}),K,t(e(b),{type:"vertical"}),M]),_:1})]),default:o(()=>[t(e(v),{modelValue:i.value,"onUpdate:modelValue":m[0]||(m[0]=d=>i.value=d),"force-fallback":e(A),style:{width:"100%"},onChange:p},{item:o(({element:d})=>[t(e(I),{style:{cursor:"ns-resize"}},{default:o(()=>[s("span",O,"/"+_(d.path),1),s("span",W,_(d.name),1),t(e(S),{checked:d.visible,"onUpdate:checked":k=>d.visible=k,type:"checkbox",onChange:p},null,8,["checked","onUpdate:checked"])]),_:2},1024)]),_:1},8,["modelValue","force-fallback"])]),_:1})]),_:1}))}}),z={style:{width:"50%"}},H={style:{width:"50%"}},Ue=y({__name:"SidebarEditor",setup(r){const{result:a,loading:n}=R(()=>T.get());return(i,p)=>(u(),f($,null,{default:o(()=>[e(n)||!e(a)?(u(),f(N,{key:0})):(u(),f(e(B),{key:1,style:{width:"100%"}},{default:o(()=>[t(e(w),null,{default:o(()=>[h("Sidebar")]),_:1}),t(e(g),{gap:"40"},{default:o(()=>[s("div",z,[t(q,{modelValue:e(a).sidebar,"onUpdate:modelValue":p[0]||(p[0]=l=>e(a).sidebar=l),workspace:e(a)},null,8,["modelValue","workspace"])]),s("div",H,[t(U,{workspace:e(a),"widgets-visible":!1},null,8,["workspace"])])]),_:1})]),_:1}))]),_:1}))}});export{Ue as default};
//# sourceMappingURL=SidebarEditor.6525d103.js.map
