import{O as i}from"./index.5912e808.js";import{A as d}from"./Title.dfd37452.js";import"./index.2623066f.js";import{A as l}from"./Text.b10c1140.js";import{d as c,o as u,b as f,ew as m,f as o,w as a,u as r,as as n}from"./outputWidgets.6e1c5425.js";import"./fetch.d2d3ed34.js";import"./pubsub.4f3043c8.js";import"./Base.0277cf44.js";import"./Link.5b1de2a9.js";import"./Paragraph.4ce326b3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="4bd47ee8-401f-4050-a53c-646cfd085ca0",e._sentryDebugIdIdentifier="sentry-dbid-4bd47ee8-401f-4050-a53c-646cfd085ca0")}catch{}})();const x=c({__name:"OidcLoginCallback",setup(e){return u(async()=>{await new i().loginCallback()}),(t,s)=>(f(),m("div",null,[o(r(d),null,{default:a(()=>[n("You're authenticated")]),_:1}),o(r(l),null,{default:a(()=>[n(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{x as default};
//# sourceMappingURL=OidcLoginCallback.0f99f042.js.map
