import{F as b}from"./PhArrowSquareOut.vue.b51cdf06.js";import{a as h}from"./asyncComputed.06ede41f.js";import{d as k,J as v,eK as w,b as r,ew as d,c as f,w as s,u as e,ex as x,as as m,aE as C,eF as I,f as c,eH as D,x as F}from"./outputWidgets.6e1c5425.js";import{g as H}from"./api.eb323d7c.js";import"./index.2623066f.js";import"./index.088b8677.js";import{A as u}from"./index.c12e1c2f.js";import{a as _}from"./Base.0277cf44.js";import{C as T}from"./Card.8d975aac.js";import"./index.5912e808.js";import"./fetch.d2d3ed34.js";import"./pubsub.4f3043c8.js";import"./runnerData.dbd7d7cb.js";import"./url.5357e9db.js";import"./Link.5b1de2a9.js";import"./Paragraph.4ce326b3.js";import"./Text.b10c1140.js";import"./Title.dfd37452.js";import"./TabPane.6f71397e.js";import"./hasIn.bf07751b.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="b80379df-85f6-4c35-84f4-5be8e5af0f18",t._sentryDebugIdIdentifier="sentry-dbid-b80379df-85f6-4c35-84f4-5be8e5af0f18")}catch{}})();const z=k({__name:"Home",setup(t){const{result:a}=h(H),i=v(()=>{var o,p;return(p=(o=a.value)==null?void 0:o.sidebar.filter(n=>n.visible))!=null?p:[]}),y=w(),g=o=>{y.push({path:`/${o}`})};return(o,p)=>{var n;return r(),d("div",{class:"container",style:x({backgroundColor:(n=e(a))==null?void 0:n.theme})},[i.value.length===0?(r(),f(e(_),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:s(()=>[m(" There are no public forms available ")]),_:1})):(r(),f(e(u),{key:1,vertical:"",gap:"large",style:{padding:"120px 0"}},{default:s(()=>[(r(!0),d(C,null,I(i.value,l=>(r(),f(e(T),{key:l.id,class:"form-card",onClick:B=>g(l.path)},{default:s(()=>[c(e(u),{gap:"large",align:"center",justify:"space-between"},{default:s(()=>[c(e(_),{style:{"font-size":"18px","font-weight":"500"}},{default:s(()=>[m(D(l.name),1)]),_:2},1024),c(e(b),{color:"#000",width:"20"})]),_:2},1024)]),_:2},1032,["onClick"]))),128))]),_:1}))],4)}}});const Y=F(z,[["__scopeId","data-v-37a2f4ae"]]);export{Y as default};
//# sourceMappingURL=Home.7e476090.js.map
