import{a as g}from"./asyncComputed.06ede41f.js";import{d as y,eE as _,o as b,u as e,b as l,c as w,ew as x,f as a,w as o,as as p,bG as h,e as C,eH as I}from"./outputWidgets.6e1c5425.js";import{c}from"./router.4a0ba06b.js";import"./index.76daa7f6.js";import{O as k}from"./organization.87dbdb1d.js";import{L as v}from"./LoadingContainer.74576226.js";import{A}from"./Title.dfd37452.js";import{A as B}from"./index.c12e1c2f.js";import{A as D}from"./index.e3b3130d.js";import{C as N}from"./Card.8d975aac.js";import"./Form.b82a2cec.js";import"./hasIn.bf07751b.js";import"./popupNotifcation.76f4dd63.js";import"./record.c7d63161.js";import"./pubsub.4f3043c8.js";import"./Base.0277cf44.js";import"./TabPane.6f71397e.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="d6c4abbb-fa2c-4e32-8793-e97868c23154",t._sentryDebugIdIdentifier="sentry-dbid-d6c4abbb-fa2c-4e32-8793-e97868c23154")}catch{}})();const z={key:1},M={style:{display:"flex","justify-content":"flex-start","font-size":"24px"}},Y=y({__name:"Billing",setup(t){const r=_().params.organizationId,{loading:m,result:f}=g(()=>k.get(r));b(()=>{location.search.includes("upgrade")&&c.showNewMessage("I want to upgrade my plan")});const u=()=>c.showNewMessage("I want to upgrade my plan");return(E,V)=>e(m)?(l(),w(v,{key:0})):(l(),x("div",z,[a(e(B),{justify:"space-between",align:"center"},{default:o(()=>[a(e(A),{level:3},{default:o(()=>[p("Current plan")]),_:1})]),_:1}),a(e(D),{style:{"margin-top":"0"}}),a(e(N),{style:{width:"300px"},title:"Plan"},{extra:o(()=>[a(e(h),{onClick:u},{default:o(()=>[p("Upgrade")]),_:1})]),default:o(()=>{var s,i,d;return[C("div",M,I((d=(i=(s=e(f))==null?void 0:s.billingMetadata)==null?void 0:i.plan)!=null?d:"No active plan"),1)]}),_:1})]))}});export{Y as default};
//# sourceMappingURL=Billing.b189c682.js.map
