import{u as c}from"./index.5912e808.js";import{d as l,r as d,b as r,ew as u,f,u as a,c as p,ey as s,L as y}from"./outputWidgets.6e1c5425.js";import{K as g,_ as k,A as _,P as v}from"./TableView.vue_vue_type_script_setup_true_lang.f105b085.js";import{A as w}from"./index.9e9aacd6.js";import"./fetch.d2d3ed34.js";import"./pubsub.4f3043c8.js";import"./vuedraggable.umd.203fdeb3.js";import"./workspaces.0676e56f.js";import"./runnerData.dbd7d7cb.js";import"./url.5357e9db.js";import"./record.c7d63161.js";import"./asyncComputed.06ede41f.js";import"./scripts.29615e06.js";import"./envVars.72a577f4.js";import"./api.6ad56b41.js";import"./metadata.85c4f3ac.js";import"./PhCheckCircle.vue.c66a4019.js";import"./PhScroll.vue.1ea6100a.js";import"./PhWebhooksLogo.vue.9951768a.js";import"./ant-design.f246aa2b.js";import"./index.1a6a6e78.js";import"./Modal.e50e9e9a.js";import"./Text.b10c1140.js";import"./Base.0277cf44.js";import"./index.c12e1c2f.js";import"./index.1442882a.js";import"./index.1932d206.js";import"./Paragraph.4ce326b3.js";import"./index.2623066f.js";import"./Link.5b1de2a9.js";import"./Title.dfd37452.js";import"./index.181c30ec.js";import"./CollapsePanel.98f2e9e0.js";import"./index.e3b3130d.js";import"./index.19929efb.js";import"./isNumeric.75337b1e.js";import"./Card.8d975aac.js";import"./TabPane.6f71397e.js";import"./hasIn.bf07751b.js";import"./LoadingOutlined.3409bcb9.js";import"./index.9a8c87ee.js";import"./Form.b82a2cec.js";import"./string.21869e46.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="ac6b3a74-81ec-411f-a343-1751c9c98e0a",t._sentryDebugIdIdentifier="sentry-dbid-ac6b3a74-81ec-411f-a343-1751c9c98e0a")}catch{}})();const x={style:{padding:"20px",width:"100vw","box-sizing":"border-box"}},dt=l({__name:"Threads",setup(t){const e=new v(c),n=new y(_,"kanban-selected-stages"),m=["Kanban","Table view"],o=d("Kanban");return(K,i)=>(r(),u("div",x,[f(a(w),{value:o.value,"onUpdate:value":i[0]||(i[0]=b=>o.value=b),options:m,style:{"margin-bottom":"16px"}},null,8,["value"]),o.value==="Kanban"?(r(),p(g,{key:0,"kanban-repository":a(e),"kanban-stages-storage":a(n)},null,8,["kanban-repository","kanban-stages-storage"])):s("",!0),o.value==="Table view"?(r(),p(k,{key:1,"kanban-repository":a(e)},null,8,["kanban-repository"])):s("",!0)]))}});export{dt as default};
//# sourceMappingURL=Threads.5a581c5f.js.map
