import{f,eI as d,eW as u}from"./outputWidgets.6e1c5425.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="43e7646f-b834-45eb-b13e-0a55eef6113c",e._sentryDebugIdIdentifier="sentry-dbid-43e7646f-b834-45eb-b13e-0a55eef6113c")}catch{}})();function o(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(i){return Object.getOwnPropertyDescriptor(n,i).enumerable}))),r.forEach(function(i){l(e,i,n[i])})}return e}function l(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var a=function(t,n){var r=o({},t,n.attrs);return f(d,o({},r,{icon:u}),null)};a.displayName="LoadingOutlined";a.inheritAttrs=!1;const b=a;export{b as L};
//# sourceMappingURL=LoadingOutlined.3409bcb9.js.map
