.page[data-v-37a2f4ae]{display:flex;flex-direction:column;height:100%}.container[data-v-37a2f4ae]{display:flex;justify-content:center;align-items:center;width:100%;flex:1}.form-card[data-v-37a2f4ae]{cursor:pointer}.form-card[data-v-37a2f4ae]:hover{box-shadow:0 0 10px #0000001a}
