import{u as a}from"./index.5912e808.js";import{d as c,eK as d,eE as i,b as p,ew as _,f as u,x as f}from"./outputWidgets.6e1c5425.js";import{_ as m}from"./Login.vue_vue_type_script_setup_true_lang.b3cb44e1.js";import"./fetch.d2d3ed34.js";import"./pubsub.4f3043c8.js";import"./Link.5b1de2a9.js";import"./Base.0277cf44.js";import"./index.0b7245cc.js";import"./PhArrowClockwise.vue.ce26992a.js";import"./CircularLoading.f493f8ac.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="69c4c55b-24f2-4f7c-8910-1104cf6317b7",e._sentryDebugIdIdentifier="sentry-dbid-69c4c55b-24f2-4f7c-8910-1104cf6317b7")}catch{}})();const l={class:"login"},y=c({__name:"Login",setup(e){const t=d(),o=i(),n=async()=>{await a.signUp();const{redirect:s,...r}=o.query;if(s){t.push({path:s,query:r,params:o.params});return}t.push({name:"playerThreads",query:r})};return(s,r)=>(p(),_("div",l,[u(m,{onDone:n})]))}});const L=f(y,[["__scopeId","data-v-064dd72d"]]);export{L as default};
//# sourceMappingURL=Login.659f55a4.js.map
