import{W as s,f as d,S as p}from"./outputWidgets.6e1c5425.js";import{B as f,b as i}from"./Base.0277cf44.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="ab99ed89-45ee-4c9f-a888-039299ddf3e1",e._sentryDebugIdIdentifier="sentry-dbid-ab99ed89-45ee-4c9f-a888-039299ddf3e1")}catch{}})();const y=()=>p(i(),["component"]),r=(e,a)=>{let{slots:t,attrs:o}=a;const n=s(s(s({},e),{component:"div"}),o);return d(f,n,t)};r.displayName="ATypographyParagraph";r.inheritAttrs=!1;r.props=y();const b=r;export{b as A};
//# sourceMappingURL=Paragraph.4ce326b3.js.map
