import{D as l}from"./DeleteOutlined.f8ba9770.js";import{f as u,eI as o}from"./outputWidgets.6e1c5425.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="2afe0cd5-2801-4a6e-9510-aceef4554933",e._sentryDebugIdIdentifier="sentry-dbid-2afe0cd5-2801-4a6e-9510-aceef4554933")}catch{}})();function i(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(a){return Object.getOwnPropertyDescriptor(n,a).enumerable}))),r.forEach(function(a){d(e,a,n[a])})}return e}function d(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var f=function(t,n){var r=i({},t,n.attrs);return u(o,i({},r,{icon:l}),null)};f.displayName="DeleteOutlined";f.inheritAttrs=!1;const b=f;export{b as D};
//# sourceMappingURL=DeleteOutlined.6ea9eddf.js.map
