import{ad as p,W as t,S as r,f}from"./outputWidgets.6e1c5425.js";import{B as l,b as c}from"./Base.0277cf44.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="fc17a06e-0485-4d18-9c79-e5d8e0e83626",e._sentryDebugIdIdentifier="sentry-dbid-fc17a06e-0485-4d18-9c79-e5d8e0e83626")}catch{}})();const y=()=>t(t({},r(c(),["component"])),{ellipsis:{type:[Boolean,Object],default:void 0}}),o=(e,s)=>{let{slots:a,attrs:d}=s;const{ellipsis:n}=e;p();const i=t(t(t({},e),{ellipsis:n&&typeof n=="object"?r(n,["expandable","rows"]):n,component:"span"}),d);return f(l,i,a)};o.displayName="ATypographyText";o.inheritAttrs=!1;o.props=y();const g=o;export{g as A};
//# sourceMappingURL=Text.b10c1140.js.map
