import{O as d}from"./index.5912e808.js";import{d as i,o as l,b as c,ew as u,f as o,w as a,u as r,as as n}from"./outputWidgets.6e1c5425.js";import{A as f}from"./Title.dfd37452.js";import{A as m}from"./Text.b10c1140.js";import"./fetch.d2d3ed34.js";import"./pubsub.4f3043c8.js";import"./Base.0277cf44.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="337f1b6c-0325-4e9c-9abd-54fce3c4337a",e._sentryDebugIdIdentifier="sentry-dbid-337f1b6c-0325-4e9c-9abd-54fce3c4337a")}catch{}})();const I=i({__name:"OidcLogoutCallback",setup(e){return l(async()=>{await new d().logoutCallback()}),(t,s)=>(c(),u("div",null,[o(r(f),null,{default:a(()=>[n("You're authenticated")]),_:1}),o(r(m),null,{default:a(()=>[n(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{I as default};
//# sourceMappingURL=OidcLogoutCallback.8f6ec645.js.map
