import{F as t}from"./Form.b82a2cec.js";import{b3 as r,cl as n}from"./outputWidgets.6e1c5425.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="317d88e8-f113-4744-b3f7-181484338d24",e._sentryDebugIdIdentifier="sentry-dbid-317d88e8-f113-4744-b3f7-181484338d24")}catch{}})();t.useInjectFormItemContext=r;t.ItemRest=n;t.install=function(e){return e.component(t.name,t),e.component(t.Item.name,t.Item),e.component(n.name,n),e};
//# sourceMappingURL=index.9a8c87ee.js.map
