import{x as d,b as o,ew as n,dj as s,e as r,ey as a}from"./outputWidgets.6e1c5425.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="c565737b-e5cd-428c-b06e-fee8ee31df67",e._sentryDebugIdIdentifier="sentry-dbid-c565737b-e5cd-428c-b06e-fee8ee31df67")}catch{}})();const c={},f={class:"base-layout"},i={class:"base-middle"},u={key:0,class:"base-footer"};function _(e,t){return o(),n("div",f,[s(e.$slots,"navbar",{},void 0,!0),r("section",i,[s(e.$slots,"sidebar",{},void 0,!0),s(e.$slots,"content",{},void 0,!0)]),e.$slots.footer?(o(),n("section",u,[s(e.$slots,"footer",{},void 0,!0)])):a("",!0)])}const y=d(c,[["render",_],["__scopeId","data-v-e54815f3"]]);export{y as B};
//# sourceMappingURL=BaseLayout.6e2aa643.js.map
