import{d as o,b as a,ew as s,e as d,dj as r,eA as l,x as _}from"./outputWidgets.6e1c5425.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="a9706153-ba4f-4bd3-9f63-0233ac544023",e._sentryDebugIdIdentifier="sentry-dbid-a9706153-ba4f-4bd3-9f63-0233ac544023")}catch{}})();const f={class:"content-layout"},c=o({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,n)=>(a(),s("div",f,[d("div",{class:l(["centered-layout",{"full-width":t.fullWidth}])},[r(t.$slots,"default",{},void 0,!0)],2)]))}});const i=_(c,[["__scopeId","data-v-00ef87a4"]]);export{i as C};
//# sourceMappingURL=ContentLayout.150390bd.js.map
