.terminal[data-v-4e71a195]{margin-top:20px;width:96%;background-color:#212427;padding:12px 16px;border-radius:8px;overflow:scroll}.log-text[data-v-4e71a195]{color:#fff;margin:4px}.panel[data-v-b7151dd7] .ant-collapse-header{padding:0}[data-v-0fd81111]:root{--main-font-family: DM Sans, sans-serif}[data-v-0fd81111]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-0fd81111]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-0fd81111]{background-color:#fff;padding:10px}.stage-column[data-v-0fd81111]{background-color:#e9eaeb;border-radius:6px;padding:8px;height:fit-content;width:300px}.tag[data-v-0fd81111]{max-width:250px}.skeleton[data-v-0fd81111] .ant-skeleton-button{height:200px}[data-v-08e39e62]:root{--main-font-family: DM Sans, sans-serif}[data-v-08e39e62]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-08e39e62]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-08e39e62]{background-color:#fff;padding:10px}.tag[data-v-08e39e62]{background-color:#e9eaeb;cursor:pointer;max-width:275px}[data-v-915ead59]:root{--main-font-family: DM Sans, sans-serif}[data-v-915ead59]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-915ead59]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-915ead59]{background-color:#fff;padding:10px}.stages-container[data-v-915ead59]{max-width:100vw;position:relative;flex-grow:1;display:flex}.stages-container .stages-content[data-v-915ead59]{overflow:auto}.stages-container .stages-content[data-v-915ead59] .ant-select-selection-item{display:flex;align-items:center}.stages-container .stages-content .draggable[data-v-915ead59]{display:flex;gap:8px}.stages-container .stages-content .stages-content-column[data-v-915ead59]{cursor:grab}.ghost[data-v-915ead59]{opacity:.5;background-color:#8692a5}
