import{C as t,E as i,K as d,a as b,M as c,c as l,P as y,R as f,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.5ee3c63e.js";import"./outputWidgets.6e1c5425.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="37ee9305-480b-4aaa-a7e7-61248465d4bc",e._sentryDebugIdIdentifier="sentry-dbid-37ee9305-480b-4aaa-a7e7-61248465d4bc")}catch{}})();export{t as CancellationTokenSource,i as Emitter,d as KeyCode,b as KeyMod,c as MarkerSeverity,l as MarkerTag,y as Position,f as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.c054c01f.js.map
