import{C as d}from"./ContentLayout.150390bd.js";import{A as l,K as y,_ as k,E as g}from"./TableView.vue_vue_type_script_setup_true_lang.f105b085.js";import{d as _,r as w,b as n,c as i,w as m,L as h,f as s,u as e,ey as c}from"./outputWidgets.6e1c5425.js";import{l as v}from"./fetch.d2d3ed34.js";import{A as f,T}from"./TabPane.6f71397e.js";import"./Card.8d975aac.js";import"./vuedraggable.umd.203fdeb3.js";import"./workspaces.0676e56f.js";import"./runnerData.dbd7d7cb.js";import"./url.5357e9db.js";import"./record.c7d63161.js";import"./pubsub.4f3043c8.js";import"./asyncComputed.06ede41f.js";import"./scripts.29615e06.js";import"./envVars.72a577f4.js";import"./api.6ad56b41.js";import"./metadata.85c4f3ac.js";import"./PhCheckCircle.vue.c66a4019.js";import"./PhScroll.vue.1ea6100a.js";import"./PhWebhooksLogo.vue.9951768a.js";import"./ant-design.f246aa2b.js";import"./index.1a6a6e78.js";import"./Modal.e50e9e9a.js";import"./Text.b10c1140.js";import"./Base.0277cf44.js";import"./index.c12e1c2f.js";import"./index.1442882a.js";import"./index.1932d206.js";import"./Paragraph.4ce326b3.js";import"./index.2623066f.js";import"./Link.5b1de2a9.js";import"./Title.dfd37452.js";import"./index.181c30ec.js";import"./CollapsePanel.98f2e9e0.js";import"./index.e3b3130d.js";import"./index.19929efb.js";import"./isNumeric.75337b1e.js";import"./LoadingOutlined.3409bcb9.js";import"./index.9a8c87ee.js";import"./Form.b82a2cec.js";import"./hasIn.bf07751b.js";import"./string.21869e46.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="209832ca-6e3a-43b1-8e17-9f11f4efc050",o._sentryDebugIdIdentifier="sentry-dbid-209832ca-6e3a-43b1-8e17-9f11f4efc050")}catch{}})();class K{constructor(t=v){this.fetch=t}async fork(t){return(await this.fetch("/_editor/api/stage_runs/fork",{method:"POST",body:JSON.stringify({stage_run_id:t}),headers:{"Content-Type":"application/json"}})).json()}}const dt=_({__name:"WorkflowThreads",setup(o){const t=new g,r=new K,b=new h(l,"kanban-selected-stages"),a=w("kanban");return(S,p)=>(n(),i(d,{"full-width":""},{default:m(()=>[s(e(T),{activeKey:a.value,"onUpdate:activeKey":p[0]||(p[0]=u=>a.value=u)},{default:m(()=>[s(e(f),{key:"kanban",tab:"Kanban View"}),s(e(f),{key:"table",tab:"Table View"})]),_:1},8,["activeKey"]),a.value==="kanban"?(n(),i(y,{key:0,"kanban-repository":e(t),"kanban-stages-storage":e(b),"stage-run-repository":e(r)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):c("",!0),a.value==="table"?(n(),i(k,{key:1,"kanban-repository":e(t)},null,8,["kanban-repository"])):c("",!0)]),_:1}))}});export{dt as default};
//# sourceMappingURL=WorkflowThreads.b2b0fa8c.js.map
