import{e_ as n,e$ as t}from"./outputWidgets.6e1c5425.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="c7c04b62-f170-48d9-9fd6-d97039ded556",e._sentryDebugIdIdentifier="sentry-dbid-c7c04b62-f170-48d9-9fd6-d97039ded556")}catch{}})();function o(e,d){return n(1,arguments),t(e,Date.now(),d)}export{o as f};
//# sourceMappingURL=index.1932d206.js.map
