import{W as s}from"./outputWidgets.6e1c5425.js";import{c as i,d}from"./index.a9b06ab4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="e0fa662a-0aca-475e-887f-bd594376ca33",e._sentryDebugIdIdentifier="sentry-dbid-e0fa662a-0aca-475e-887f-bd594376ca33")}catch{}})();const{DatePicker:n,WeekPicker:a,MonthPicker:r,YearPicker:f,TimePicker:m,QuarterPicker:t,RangePicker:o}=i(d),b=s(n,{WeekPicker:a,MonthPicker:r,YearPicker:f,RangePicker:o,TimePicker:m,QuarterPicker:t,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(r.name,r),e.component(a.name,a),e.component(t.name,t),e)});export{b as D,r as M,t as Q,o as R,a as W};
//# sourceMappingURL=dayjs.219647cd.js.map
