import{d as o,eE as d,b as c,ew as u,e as a,eH as r,x as _}from"./outputWidgets.6e1c5425.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new l().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="17faa506-5a59-47be-8d86-3dd2756dd077",e._sentryDebugIdIdentifier="sentry-dbid-17faa506-5a59-47be-8d86-3dd2756dd077")}catch{}})();const i={class:"inner-content"},f=o({__name:"Error",setup(e){const s=d(),n=()=>{const{status:t}=s.params;switch(t){case"404":return{status:t,message:"Page not found."};case"403":return{status:t,message:"Access denied. Please contact your administrator."};default:return{status:"500",message:"An unknown error ocurred. Please try again or contact support."}}};return(t,p)=>(c(),u("div",i,[a("h1",null,r(n().status),1),a("p",null,r(n().message),1)]))}});const l=_(f,[["__scopeId","data-v-5e6b9e6f"]]);export{l as default};
//# sourceMappingURL=Error.d42a162f.js.map
