import"./outputWidgets.6e1c5425.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="0809f8dd-cd4d-4099-968d-7c4d4506ee47",e._sentryDebugIdIdentifier="sentry-dbid-0809f8dd-cd4d-4099-968d-7c4d4506ee47")}catch{}})();const c=e=>{try{return new URL(e),!0}catch{return!1}},o=(e,r)=>{if(!Object.keys(r).length)return e;const t=new URL(e),n=new URLSearchParams(t.search);return Object.entries(r).forEach(([d,s])=>{t.searchParams.delete(d),n.set(d,s)}),`${t.origin}${t.pathname}?${n.toString()}`};export{c as i,o as m};
//# sourceMappingURL=url.5357e9db.js.map
