import{B as d}from"./BookOutlined.8202b78f.js";import{d as f,b as a,c as l,w as o,f as c,u as n,dj as u,ew as i,as as b,aE as p,bG as y}from"./outputWidgets.6e1c5425.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="4a7fdbe6-4b6f-4710-a862-020e775f422b",t._sentryDebugIdIdentifier="sentry-dbid-4a7fdbe6-4b6f-4710-a862-020e775f422b")}catch{}})();const k=f({__name:"DocsButton",props:{path:{}},setup(t){return(e,r)=>{var s;return a(),l(n(y),{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank",type:"link",style:{color:"#d14056"},size:"small"},{icon:o(()=>[c(n(d))]),default:o(()=>[e.$slots.default?u(e.$slots,"default",{key:0}):(a(),i(p,{key:1},[b("Docs")],64))]),_:3},8,["href"])}}});export{k as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.3a6e05dd.js.map
