import{g as b}from"./api.eb323d7c.js";import{u as i}from"./index.5912e808.js";import{d as g,eK as h,r as v,K as k,a as w,b as r,ew as I,f as W,u as e,c as m,w as x,ey as C,x as L}from"./outputWidgets.6e1c5425.js";import{P as D}from"./PlayerNavbar.854285c0.js";import{a as d}from"./asyncComputed.06ede41f.js";import{L as K}from"./CircularLoading.f493f8ac.js";import{W as N}from"./WidgetsFrame.89e32c21.js";import"./runnerData.dbd7d7cb.js";import"./url.5357e9db.js";import"./fetch.d2d3ed34.js";import"./pubsub.4f3043c8.js";import"./PhKanban.vue.0b81dffb.js";import"./PhSignOut.vue.8b6374ae.js";import"./index.2d522974.js";import"./Text.b10c1140.js";import"./Base.0277cf44.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[t]="11013608-0060-4ce7-9fe6-ab99c90b5d8e",a._sentryDebugIdIdentifier="sentry-dbid-11013608-0060-4ce7-9fe6-ab99c90b5d8e")}catch{}})();const V={class:"page"},B=g({__name:"Workspace",setup(a){const t=h(),s=v(i.getUser()),{result:l,refetch:p}=d(async()=>(await i.allow("kanban")).status==="ALLOWED");k(s,()=>p());const u=({path:n})=>{t.push({name:"form",params:{path:n.split("/")}})},{result:o,loading:f}=d(b),_=()=>{i.removeUser(),t.push({name:"playerHome"})};return(n,E)=>{var c;const y=w("router-view");return r(),I("div",V,[W(D,{"runner-data":e(o),"is-kanban-visible":e(l)||!1,"user-email":(c=s.value)==null?void 0:c.claims.email,onNavigate:u,onLogout:_},null,8,["runner-data","is-kanban-visible","user-email"]),e(o)?(r(),m(N,{key:0,"main-color":e(o).mainColor,theme:e(o).theme,"font-family":e(o).fontFamily,style:{height:"100vh",width:"100%"}},{default:x(()=>[e(f)?(r(),m(K,{key:0})):(r(),m(y,{key:1}))]),_:1},8,["main-color","theme","font-family"])):C("",!0)])}}});const X=L(B,[["__scopeId","data-v-df3ff1d8"]]);export{X as default};
//# sourceMappingURL=Workspace.117c8ec5.js.map
