import{x as r,a as i,b as a,c as d,j as c,T as p,k as f,P as _,C as u,M as b,s as l,l as s,m as g,n as m,p as y,q as v}from"./outputWidgets.6e1c5425.js";import{s as w,a as o}from"./index.5912e808.js";import"./fetch.d2d3ed34.js";import"./pubsub.4f3043c8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="f79bc0bc-8ddf-4379-8316-f07bdd82cda1",e._sentryDebugIdIdentifier="sentry-dbid-f79bc0bc-8ddf-4379-8316-f07bdd82cda1")}catch{}})();const h={};function I(e,t){const n=i("router-view");return a(),d(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const k=r(h,[["render",I]]);class x{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await w();const e=c({render:()=>g(k)});p.init(),f(e,o),x.init(),e.use(o),e.use(_),e.mount("#app"),e.component("VSelect",u),e.component("Markdown",b),e.component("Message",l),s(e,m),s(e,y),s(e,v)})();
//# sourceMappingURL=player.24cf2117.js.map
