import{f as o,eI as u,eP as c}from"./outputWidgets.6e1c5425.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="14da931b-a5b6-465e-9825-082ab039a8c9",e._sentryDebugIdIdentifier="sentry-dbid-14da931b-a5b6-465e-9825-082ab039a8c9")}catch{}})();function l(e){for(var t=1;t<arguments.length;t++){var r=arguments[t]!=null?Object(arguments[t]):{},n=Object.keys(r);typeof Object.getOwnPropertySymbols=="function"&&(n=n.concat(Object.getOwnPropertySymbols(r).filter(function(a){return Object.getOwnPropertyDescriptor(r,a).enumerable}))),n.forEach(function(a){d(e,a,r[a])})}return e}function d(e,t,r){return t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}var i=function(t,r){var n=l({},t,r.attrs);return o(u,l({},n,{icon:c}),null)};i.displayName="CloseCircleOutlined";i.inheritAttrs=!1;const s=i;export{s as C};
//# sourceMappingURL=CloseCircleOutlined.683f9a4c.js.map
