import{d,b as t,ew as o,f as s,u as r,bh as _,x as i}from"./outputWidgets.6e1c5425.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="d7d1199a-988f-4ad0-8128-f36472e0ba45",e._sentryDebugIdIdentifier="sentry-dbid-d7d1199a-988f-4ad0-8128-f36472e0ba45")}catch{}})();const c={class:"centered"},f=d({__name:"LoadingContainer",setup(e){return(n,a)=>(t(),o("div",c,[s(r(_))]))}});const u=i(f,[["__scopeId","data-v-1da18eee"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.74576226.js.map
